@@ -17,7 +17,9 @@ use warnings;
 
 {
     package Doit;
-    our $VERSION = '0.023_50';
+    our $VERSION = '0.024_50';
+
+    use constant IS_WIN => $^O eq 'MSWin32';
 }
 
 {
@@ -40,7 +42,7 @@ use warnings;
 	    # XXX Probably should also check if the terminal is ANSI-capable at all
 	    # XXX Probably should not use coloring on non-terminals (but
 	    #     there could be a --color option like in git to force it)
-	    $can_coloring = $^O ne 'MSWin32' && eval { require Term::ANSIColor; 1 } ? 1 : 0;
+	    $can_coloring = !Doit::IS_WIN && eval { require Term::ANSIColor; 1 } ? 1 : 0;
 	}
     }
 
@@ -336,13 +338,19 @@ use warnings;
     sub _new {
 	my $class = shift;
 	my $self = bless { }, $class;
-	# XXX hmmm, creating now self-refential data structures ...
-	$self->{runner}    = Doit::Runner->new($self);
-	$self->{dryrunner} = Doit::Runner->new($self, 1);
 	$self;
     }
-    sub runner    { shift->{runner} }
-    sub dryrunner { shift->{dryrunner} }
+    sub runner {
+	my($self) = @_;
+	# XXX hmmm, creating now self-refential data structures ...
+	$self->{runner} ||= Doit::Runner->new($self);
+    }
+	    
+    sub dryrunner {
+	my($self) = @_;
+	# XXX hmmm, creating now self-refential data structures ...
+	$self->{dryrunner} ||= Doit::Runner->new($self, dryrun => 1);
+    }
 
     sub init {
 	my($class) = @_;
@@ -758,7 +766,7 @@ use warnings;
 	my $instr = delete $options{instr}; $instr = '' if !defined $instr;
 	error "Unhandled options: " . join(" ", %options) if %options;
 
-	@args = Doit::Win32Util::win32_quote_list(@args) if $^O eq 'MSWin32';
+	@args = Doit::Win32Util::win32_quote_list(@args) if Doit::IS_WIN;
 
 	require IPC::Open2;
 
@@ -801,7 +809,7 @@ use warnings;
 	my $statusref = delete $options{statusref};
 	error "Unhandled options: " . join(" ", %options) if %options;
 
-	@args = Doit::Win32Util::win32_quote_list(@args) if $^O eq 'MSWin32';
+	@args = Doit::Win32Util::win32_quote_list(@args) if Doit::IS_WIN;
 
 	require IO::Select;
 	require IPC::Open3;
@@ -868,7 +876,7 @@ use warnings;
 
     sub _qx {
 	my(@args) = @_;
-	@args = Doit::Win32Util::win32_quote_list(@args) if $^O eq 'MSWin32';
+	@args = Doit::Win32Util::win32_quote_list(@args) if Doit::IS_WIN;
 
 	open my $fh, '-|', @args
 	    or error "Error running '@args': $!";
@@ -996,7 +1004,7 @@ use warnings;
     sub cmd_system {
 	my($self, @args) = @_;
 	my %options; if (@args && ref $args[0] eq 'HASH') { %options = %{ shift @args } }
-	@args = Doit::Win32Util::win32_quote_list(@args) if $^O eq 'MSWin32';
+	@args = Doit::Win32Util::win32_quote_list(@args) if Doit::IS_WIN;
 	my $show_cwd = delete $options{show_cwd};
 	error "Unhandled options: " . join(" ", %options) if %options;
 	my @commands;
@@ -1522,8 +1530,10 @@ use warnings;
 {
     package Doit::Runner;
     sub new {
-	my($class, $X, $dryrun) = @_;
-	bless { X => $X, dryrun => $dryrun, components => [] }, $class;
+	my($class, $Doit, %options) = @_;
+	my $dryrun = delete $options{dryrun};
+	die "Unhandled options: " . join(" ", %options) if %options;
+	bless { Doit => $Doit, dryrun => $dryrun, components => [] }, $class;
     }
     sub is_dry_run { shift->{dryrun} }
 
@@ -1531,19 +1541,20 @@ use warnings;
 
     sub install_generic_cmd {
 	my($self, $name, @args) = @_;
-	$self->{X}->install_generic_cmd($name, @args);
-	install_cmd($name); # XXX hmmmm
+	$self->{Doit}->install_generic_cmd($name, @args);
+	__PACKAGE__->install_cmd($name);
     }
 
-    sub install_cmd ($) {
+    sub install_cmd {
+	shift; # $class unused
 	my $cmd = shift;
 	my $meth = 'cmd_' . $cmd;
 	my $code = sub {
 	    my($self, @args) = @_;
 	    if ($self->{dryrun}) {
-		$self->{X}->$meth(@args)->show;
+		$self->{Doit}->$meth(@args)->show;
 	    } else {
-		$self->{X}->$meth(@args)->doit;
+		$self->{Doit}->$meth(@args)->doit;
 	    }
 	};
 	no strict 'refs';
@@ -1600,7 +1611,7 @@ use warnings;
 		 qw(change_file), # own invention
 		 qw(setenv unsetenv), # $ENV manipulation
 		) {
-	install_cmd $cmd;
+	__PACKAGE__->install_cmd($cmd);
     }
 
     sub call_wrapped_method {
@@ -1660,6 +1671,8 @@ use warnings;
 	die "Please use either Doit::RPC::Client, Doit::RPC::Server or Doit::RPC::SimpleServer";
     }
 
+    sub runner { shift->{runner} }
+
     sub receive_data {
 	my($self) = @_;
 	my $fh = $self->{infh};
@@ -1843,7 +1856,7 @@ use warnings;
 		return;
 	    }
 	    $d->(" calling method $data[0]");
-	    my($rettype, @ret) = $self->{runner}->call_wrapped_method($context, @data);
+	    my($rettype, @ret) = $self->runner->call_wrapped_method($context, @data);
 	    $d->(" sending result back");
 	    $self->send_data($rettype, @ret);
 	}
@@ -1882,12 +1895,12 @@ use warnings;
 		return;
 	    }
 	    open my $oldout, ">&STDOUT" or die $!;
-	    if ($^O eq 'MSWin32') {
+	    if (Doit::IS_WIN) {
 		open STDOUT, '>', 'CON:' or die $!; # XXX????
 	    } else {
 		open STDOUT, '>', "/dev/stderr" or die $!; # XXX????
 	    }
-	    my($rettype, @ret) = $self->{runner}->call_wrapped_method($context, @data);
+	    my($rettype, @ret) = $self->runner->call_wrapped_method($context, @data);
 	    open STDOUT, ">&", $oldout or die $!;
 	    $self->send_data($rettype, @ret);
 	}
