@@ -17,7 +17,7 @@ use strict;
 use warnings;
 
 use vars qw($VERSION);
-$VERSION = '0.021';
+$VERSION = '0.023';
 
 use Doit::Log;
 use Doit::Util qw(in_directory);
@@ -142,6 +142,8 @@ sub git_short_status {
 		$untracked_marker = '*'; # will be combined later
 		last;
 	    }
+	    close $fh
+		or error "Error while running '@cmd': $!";
 	}
 
 	{
@@ -206,7 +208,7 @@ sub git_root {
     error "Unhandled options: " . join(" ", %opts) if %opts;
 
     in_directory {
-	chomp(my $dir = `git rev-parse --show-toplevel`);
+	chomp(my $dir = $self->info_qx({quiet=>1}, 'git', 'rev-parse', '--show-toplevel'));
 	$dir;
     } $directory;
 }
@@ -217,7 +219,7 @@ sub git_get_commit_hash {
     error "Unhandled options: " . join(" ", %opts) if %opts;
 
     in_directory {
-	chomp(my $commit = `git log -1 --format=%H`);
+	chomp(my $commit = $self->info_qx({quiet=>1}, 'git', 'log', '-1', '--format=%H'));
 	$commit;
     } $directory;
 }
@@ -234,7 +236,7 @@ sub git_get_commit_files {
 	my $fh = _pipe_open(@cmd)
 	    or error "Error running @cmd: $!";
 	my $first = <$fh>;
-	if ($first ne "\n") { # first line is empty for older git versions (e.g. 1.7.x)
+	if (defined $first && $first ne "\n") { # first line is empty for older git versions (e.g. 1.7.x)
 	    chomp $first;
 	    push @files, $first;
 	}
@@ -251,6 +253,8 @@ sub git_get_commit_files {
 sub git_get_changed_files {
     my($self, %opts) = @_;
     my $directory = delete $opts{directory};
+    error "Unhandled options: " . join(" ", %opts) if %opts;
+
     my @files;
     in_directory {
 	my @cmd = qw(git status --porcelain);
@@ -296,6 +300,9 @@ sub git_config {
     my $val       = delete $opts{val};
     my $unset     = delete $opts{unset};
     error "Unhandled options: " . join(" ", %opts) if %opts;
+    if (defined $val && $unset) {
+	error "Don't specify both 'unset' and 'val'";
+    }
 
     in_directory {
 	no warnings 'uninitialized'; # $old_val may be undef
@@ -303,12 +310,14 @@ sub git_config {
 	if ($unset) {
 	    if ($@) {
 		if ($@->{exitcode} == 1) {
-		    # already non-existent
+		    # already non-existent (or even invalid)
+		    0;
 		} else {
 		    error "git config $key failed with exitcode $@->{exitcode}";
 		}
 	    } else {
 		$self->system(qw(git config --unset), $key, (defined $val ? $val : ()));
+		1;
 	    }
 	} else {
 	    if (!defined $val) {
@@ -316,6 +325,9 @@ sub git_config {
 	    } else {
 		if (!defined $old_val || $old_val ne $val) {
 		    $self->system(qw(git config), $key, $val);
+		    1;
+		} else {
+		    0;
 		}
 	    }
 	}
@@ -339,7 +351,7 @@ sub _is_dir_empty {
 sub _pipe_open (@) {
     my(@cmd) = @_;
     my $fh;
-    if ($^O eq 'MSWin32' && $] < 5.022) {
+    if (Doit::IS_WIN && $] < 5.022) {
 	open $fh, '-|', Doit::Win32Util::win32_quote_list(@cmd)
 	    or return undef;
     } else {
